.. _APIReferenceImagedata:

Imagedata packages
==================

Module Axis
------------
.. automodule:: imagedata.axis
   :members:

Module cmdline
----------------
.. automodule:: imagedata.cmdline
   :members:

Module imagedata.header
------------------------
.. automodule:: imagedata.header
   :members:

Module imagedata.readdata
-------------------------
.. automodule:: imagedata.readdata
   :members:

